# Generated by Django 2.2.13 on 2020-12-15 15:31

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="ApplicationCredentials",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "client_id",
                    models.CharField(
                        help_text="Client ID to identify external API's and applications that access this API.",
                        max_length=50,
                        unique=True,
                        verbose_name="client ID",
                    ),
                ),
                (
                    "secret",
                    models.CharField(
                        help_text="Secret belonging to the client ID.",
                        max_length=255,
                        verbose_name="secret",
                    ),
                ),
            ],
            options={
                "verbose_name": "client credential",
                "verbose_name_plural": "client credentials",
            },
        ),
    ]
